from ajaxtoolkit.http import JsonResponse

from django.contrib import messages


class AjaxMiddleware(object):
    def process_template_response(self, request, response):
        if request.is_ajax() and isinstance(response, JsonResponse):
            django_messages = []

            for message in messages.get_messages(request):
                django_messages.append({ 
                    "level": message.level,
                    "message": unicode(message.message),
                    "extra_tags": message.tags,
                    })
            response.dict_content['django_messages'] = django_messages
        return response




# coding=UTF-8

from django.test import TestCase
from django.http import HttpRequest

from django.contrib import messages
from django.contrib.sessions.middleware import SessionMiddleware
from django.contrib.messages.middleware import MessageMiddleware

from hamcrest import *

from ajaxtoolkit.middleware import AjaxMiddleware
from ajaxtoolkit.http import JsonResponse

class JsonResponseTests(TestCase):

    def test_response_rendering(self):
        response = JsonResponse({'foo': 'bar'})
        response.render()
        assert_that(response.content, is_('{"foo": "bar"}'))

        response = JsonResponse({'foo': u'ελληνικά'})
        response.render()
        assert_that(response.content, is_('{"foo": "\u03b5\u03bb\u03bb\u03b7\u03bd\u03b9\u03ba\u03ac"}'))


class AjaxMiddlewareTests(TestCase):

    def test_middleware_appends_messages(self):
        request = HttpRequest()
        request.META['HTTP_X_REQUESTED_WITH'] = 'XMLHttpRequest'
        SessionMiddleware().process_request(request)
        MessageMiddleware().process_request(request)

        message = "Hello. Yes. This is dog"
        messages.info(request, message)

        response = JsonResponse()
        middleware = AjaxMiddleware()
        processed_response = middleware.process_template_response(request, response)

        assert_that(processed_response.dict_content["django_messages"][0], has_entry("message", equal_to(message)))




from setuptools import setup

setup(name='django-ajax-toolkit',
      version='0.1.1',
      url='https://github.com/Geekfish/django-ajax-toolkit',
      author="Eleni Lixourioti",
      author_email="contact@eleni.co",
      description="Ajax goodies for django projects.",
      long_description=open('README.rst').read(),
      keywords="django, ajax, utilities, http",
      license='BSD',
      platforms=['linux'],
      packages=('ajaxtoolkit',),
      include_package_data=True,
      # See http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=['Environment :: Web Environment',
                   'Framework :: Django',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: BSD License',
                   'Operating System :: Unix',
                   'Development Status :: 3 - Alpha',
                   'Programming Language :: Python']
      )



from django.http import HttpResponse

from ajaxtoolkit.jsonwrapper import json


class JsonResponse(HttpResponse):
    def __init__(self, dict_content=None, mimetype='application/json', status=None, content_type=None):
        self.dict_content = dict_content if dict_content else {}
        if type(self.dict_content) is not dict:
            raise TypeError('JsonResponse content argument must be a dictionary')
        super(JsonResponse, self).__init__('', mimetype, status, content_type)

    def render(self):
        self.content = json.dumps(self.dict_content)
        return self

